<?php


namespace CloudPrinterPlugin\Controllers;


use CloudPrinterPlugin\Helpers\OrderHelper;
use CloudPrinterPlugin\Services\ConfigService;

class IncludeSalesCostController
{
    public function __construct()
    {
        add_filter('cloudprinter_before_order_submit', [$this, 'includeOrderSalesCost'], 10, 2);
    }

    public function includeOrderSalesCost($cpOrder, $woocommerceOrder)
    {
        $configService = new ConfigService();
        if (!$configService->includeSalesCost()) {
            return $cpOrder;
        }

        $totalShippingCost = 0;
        $isFreeShipping = $woocommerceOrder->get_meta('_cp_shipping_is_free') || OrderHelper::hasFreeShippingCoupon($woocommerceOrder);

        if (!$isFreeShipping) {
            $shippingData = $woocommerceOrder->get_meta('_cp_shipping_data');
            $shippingData = $shippingData ? json_decode($shippingData, true) : [];
            foreach ($shippingData as $shipping) {
                $totalShippingCost += $shipping['price'];
            }
        }
        $subtotal = 0;

        foreach ( $woocommerceOrder->get_items() as $item ) {
            $subtotal     += $item->get_subtotal() + $item->get_subtotal_tax();
        }




        $salesCost = [
            'total_products_cost' => round($subtotal, 2),
            'total_shipping_cost' => round($totalShippingCost, 2),
            'total_vat' => round($woocommerceOrder->get_total_tax(), 2)
        ];

        $cpOrder->addCustomParameter('sales_cost', $salesCost);

        return $cpOrder;
    }
}
