<?php

namespace CloudPrinterPlugin\Helpers;

use CloudPrinterPlugin\Models\CPProduct;

/**
 * Class ProductValidationHelper
 *
 * @copyright   2019 by CloudPrinter
 * @author      Vasyl Kushniruk <vk@cloudprinter.com>
 */
class ProductValidationHelper
{
    /**
     * @return ProductValidationHelper
     */
    public static function getInstance()
    {
        return new self();
    }

    public function validate(int $productId)
    {
        $product = new CPProduct($productId);

        // Skip validation if it`s not cloudprinter product
        if ($product->get_meta('_cp_is_cloud_printer_product') !== 'yes') {
            return true;
        }

        // Check required fields
        $requiredFields = [
            'cp_product_category' => 'Product category',
            'cp_product_reference' => 'Product',
        ];

        foreach ($requiredFields as $fieldKey => $fieldName) {
            if (!$product->get_meta($fieldKey)) {
                throw new \Exception(sprintf('The field "%s" is required.', $fieldName));
            }
        }

        // Check if count_pages is set for book products.
        $isBookProduct = CloudPrinterHelper::isBookProduct($product->get_meta('cp_product_category'));
        if ($isBookProduct) {
            if (!$product->get_meta('cp_book_count_pages')) {
                throw new \Exception('The field "Count pages" is required.');
            }
        }

        // Check if files is set.
        if ($product->isStaticFileProduct()) {

            $productsFiles = $product->getProductFiles();
            $fileStorage = $product->getFileStorage();
            $requiredProductsFilesTypes = $product->getRequiredFilesTypes();

            foreach ($requiredProductsFilesTypes as $fileType) {
                if (
                    empty($productsFiles[$fileStorage][$fileType])
                    || ($fileStorage === 'external' && empty($productsFiles[$fileStorage][$fileType]['link']) )
                ) {
                    throw new \Exception('The field "' . ucfirst($fileType) . ' file" is required.');
                }
            }
        }
    }
}
