<?php

namespace CloudPrinterPlugin\Services;


class RevenueCheckService
{
    public function checkRevenue($totalCartProductsPrice, $cloudprinterProductsPrice, $printProducts)
    {
        $configService = new ConfigService();

        if (!$configService->costCheckEnabled() || ! $cloudprinterProductsPrice) {
            return true;
        }

        $minimumProductMarginPercentage = $configService->getMinProductPriceMarginPercentage();
        $minimumProductMarginPercentageAlert = $configService->getMinProductPriceMarginPercentageAlert();
        $percentageChange = ($totalCartProductsPrice - $cloudprinterProductsPrice) / $cloudprinterProductsPrice * 100;

        // Send alert to site support
        if (!empty($minimumProductMarginPercentageAlert) && $minimumProductMarginPercentageAlert > $percentageChange) {
            if ($this->needSendAlert($printProducts, $percentageChange)) {
                new \WC_Emails();
                do_action('cloudprinter_price_margin_alert', $percentageChange, $printProducts, $cloudprinterProductsPrice);
            }
        }

        if ($minimumProductMarginPercentage > $percentageChange || $percentageChange <= 0) {
            return false;
        }

        return  true;
    }

    private function needSendAlert($printProducts, $percentageChange)
    {
        // Don`t need to send alert if the same email was sent less then 1 hour
        $hash = md5(serialize($printProducts) . $percentageChange);
        if (get_transient($hash)) {
            return false;
        }

        // Add to cache with 1 hour expiration
        $cacheTime = 60 * 60;
        set_transient($hash, 1, $cacheTime);

        return true;
    }
}
