<?php
    use CloudPrinterPlugin\Helpers\SerializeHelper;

    $orderTaxes = $order->get_taxes();
    $isTaxable = wc_tax_enabled() && !empty($orderTaxes);
    $shippingPrice = 0;

    if ($isTaxable) {
        echo "<script> var taxPercentage = " . reset($orderTaxes)->get_rate_percent() . "; </script>";
    }
?>


<tbody>
    <?php
    foreach ($shippingData as $shippingItem): ?>
        <?php
            if (empty($shippingItem)) {
                continue;
            }

            $shippingName = $shippingItem['service'];
            // Support the migration from the old cloudprinter version
            if (empty($shippingItem['shipping_option'])) {
                $shippingItem['shipping_option'] = '';
            } else {
                $shippingName .= sprintf(' (%s)', $shippingItem['shipping_option']);
            }


            $shippingNameToDisplay = apply_filters('cloudprinter_shipping_name',$shippingName, $shippingItem['service'], $shippingItem['shipping_option']);

            if ($isTaxable && !$isFreeShipping) {
                $shippingItemTax = $shippingService->calculateTax(isset($shippingItem['native_price']) ? $shippingItem['native_price'] : $shippingItem['price']);
                $shippingItemTax = apply_filters('cloudprinter_custom_shipping_tax', $shippingItemTax, $order);
            } else {
                $shippingItemTax = 0;
            }
        ?>
        <tr class="shipping">
            <td class="thumb"><div></div></td>
            <td colspan="3">
                <div class="name"><?php echo $shippingNameToDisplay; ?></div>
                <div class="view">
                    <table cellspacing="0" class="display_meta">
                        <tbody>
                            <tr>
                                <th>Items:</th>
                                <td>
                                    <p><?php echo join(', ', array_intersect_key($items, array_flip($shippingItem['items']))); ?></p>
                                </td>
                            </tr>
                        </tbody>
                    </table>
                </div>
            </td>
            <td width="1%" style="text-align: right">
                <?php if ($isFreeShipping): ?>
                    Free
                <?php else: ?>
                    <span>
                        <?php
                            $shippingPrice = $shippingItem['price'] - $shippingItemTax;
                            echo wc_price($shippingPrice+ ($shippingPrice / 100 * $shippingMarginPercentage));
                        ?>
                    </span>
                <?php endif; ?>
            </td>
            <?php if ($isTaxable): ?>
                <td width="1%" style="text-align: right">
                    <span><?php echo wc_price($shippingItemTax); ?></span>
                </td>
            <?php endif; ?>
            <td width="1%"></td>
        </tr>
    <?php endforeach; ?>

    <?php if (!empty($shippingRefundAmount)): ?>
        <tr class="item" data-order_item_id="shipping">
            <td></td>
            <td colspan="3">Shipping refunded:</td>
            <td width="1%" class="line_cost">
                <small class="refunded">
                    -<span class="woocommerce-Price-amount amount">
                                <bdi><?php echo wc_price(array_sum(SerializeHelper::unserializeRecursive($shippingRefundAmount))); ?></bdi>
                            </span>
                </small>
            </td>
            <?php if ($isTaxable): ?>
                <td width="1%" class="line_cost">
                    <?php if ($shippingRefundTax): ?>
                        <small class="refunded">
                            -<span class="woocommerce-Price-amount amount">
                                <bdi><?php echo wc_price(array_sum(SerializeHelper::unserializeRecursive($shippingRefundTax))); ?></bdi>
                            </span>
                        </small>
                    <?php endif; ?>
                </td>
            <?php endif; ?>
            <td width="1%">

            </td>
        </tr>
    <?php endif; ?>

    <tr id="shipping_refund" class="refund item" data-order_item_id="shipping">
        <td colspan="2"></td>
        <td width="1%"></td>
        <td width="1%" class="line_cost" id="before_refund_fields"></td>
        <td width="1%" class="line_cost">
            <div class="refund" style="display: none">
                <input placeholder="0" type="text" class="refund_line_total wc_input_price" name="refund_line_total[shipping]" data-max-refund="<?php echo $shippingPrice; ?>">
            </div>
        </td>
        <?php if ($isTaxable): ?>
            <td width="1%" class="line_cost">
                <div class="refund" style="display: none">
                    <input placeholder="0" type="text" class="refund_line_tax wc_input_price" name="refund_line_tax[shipping][1]" data-tax_id="1">
                </div>
            </td>
        <?php endif; ?>
        <td width="1%"></td>
    </tr>

</tbody>
